.. QuadratiK documentation master file, created by
   sphinx-quickstart on Sun Nov 19 21:24:10 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

.. only:: not html

   =================
   Getting Started
   =================

   .. toctree::
      :maxdepth: 4

      getting_started/index.rst

.. only:: not html

   =================
   API Reference
   =================

   .. toctree::
      :hidden:
      :maxdepth: 4

      api_reference/index.rst

.. only:: not html

   =================
   User Guide
   =================

   .. toctree::
      :hidden:
      :maxdepth: 4

      user_guide/index.rst

.. only:: not html

   =================
   Development
   =================

   .. toctree::
      :hidden:
      :maxdepth: 4

      development/index.rst

.. only:: not html

   =================
   Changelog
   =================

   .. toctree::
      :hidden:
      :maxdepth: 4

      changelog/index.rst
